changeset 2349:0edbffa9e2e2 codereview

fixed bug with inline changes highlighter.
author Marcin Kuzminski <marcin@python-works.com>
date Mon, 28 May 2012 00:09:39 +0200
parents a07e04ef7bb4
children d787da66c292
files rhodecode/lib/diffs.py
diffstat 1 files changed, 6 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/rhodecode/lib/diffs.py	Sun May 27 23:29:18 2012 +0200
+++ b/rhodecode/lib/diffs.py	Mon May 28 00:09:39 2012 +0200
@@ -279,6 +279,7 @@
                     tag,
                     l['line'][last:]
                 )
+
             do(line)
             do(next_)
 
@@ -377,8 +378,8 @@
             pass
 
         # highlight inline changes
-        for _ in files:
-            for chunk in chunks:
+        for diff_data in files:
+            for chunk in diff_data['chunks']:
                 lineiter = iter(chunk)
                 try:
                     while 1:
@@ -434,7 +435,7 @@
                 new_lineno_class='lineno old', old_lineno_class='lineno new',
                 code_class='code', enable_comments=False, diff_lines=None):
         """
         Return udiff as html table with customized css classes
         """
         def _link_to_if(condition, label, url):
             """
@@ -535,6 +536,8 @@
 
 def differ(org_repo, org_ref, other_repo, other_ref):
     """
+    General differ between branches, bookmarks or separate but releated 
+    repositories
 
     :param org_repo:
     :type org_repo:
@@ -434,7 +435,7 @@
                 code_class='code', enable_comments=False, diff_lines=None):
         """
-        Return udiff as html table with customized css classes
+        Return given diff as html table with customized css classes
         """
         def _link_to_if(condition, label, url):